@@ -28,6 +28,57 @@
 
 static int delay_timer = 0;
 
+int fix_crappy_cgi_headers(t_cgi_info *cgi_info) {
+	char *header_end, *new_buffer, *src, *dst;
+	int count = 0, header_len;
+
+	if ((header_end = strstr(cgi_info->input_buffer, "\n\n")) == NULL) {
+		return 1;
+	}
+	header_end += 2;
+
+	/* Count EOL
+	 */
+	src = cgi_info->input_buffer;
+	while (src < header_end) {
+		if (*src == '\n') {
+			count++;
+		}
+		src++;
+	}
+
+	/* Allocate new buffer
+	 */
+	if (cgi_info->input_len + count > cgi_info->input_buffer_size) {
+		cgi_info->input_buffer_size = cgi_info->input_len + count;
+	}
+	if ((new_buffer = (char*)malloc(cgi_info->input_buffer_size + 1)) == NULL) {
+		return -1;
+	}
+
+	/* Fix EOL
+	 */
+	src = cgi_info->input_buffer;
+	dst = new_buffer;
+	while (src < header_end) {
+		if (*src == '\n') {
+			*(dst++) = '\r';
+		}
+		*(dst++) = *(src++);
+	}
+
+	/* Copy request body
+	 */
+	header_len = header_end - cgi_info->input_buffer;
+	memcpy(new_buffer + header_len + count, header_end, cgi_info->input_len - header_len + 1);
+
+	free(cgi_info->input_buffer);
+	cgi_info->input_buffer = new_buffer;
+	cgi_info->input_len += count;
+
+	return 0;
+}
+
 /*
  * Load balancer
  * ==============
@@ -51,6 +102,10 @@ t_connect_to *select_connect_to(t_fcgi_server *fcgi_server, t_ip_addr *client_ip
 	bool search_new_fcgi_server = true;
 	unsigned char i;
 
+	if ((fcgi_server == NULL) || (client_ip == NULL)) {
+		return NULL;
+	}
+
 	/* Only one connect_to?
 	 */
 	if (fcgi_server->connect_to->next == fcgi_server->connect_to) {
@@ -412,6 +467,10 @@ int connect_to_fcgi_server(t_connect_to *connect_to) {
 	struct sockaddr_in6 saddr6;
 #endif
 
+	if (connect_to == NULL) {
+		return -1;
+	}
+
 	if (connect_to->host.family == AF_INET) {
 		/* IPv4
 		 */
