@@ -12,6 +12,8 @@
 #include "command.h"
 #include "log.h"
 
+#define MAX_PASSWORD_DELAY_TIMER 60
+
 typedef struct type_client {
 	t_session *session;
 	int delayed_remove;
@@ -32,6 +34,9 @@ static t_client *client_list[256];
 static pthread_mutex_t client_mutex[256];
 static t_banned *banlist;
 static pthread_mutex_t ban_mutex;
+static t_ipcounterlist *wrong_password_list;
+static pthread_mutex_t pwd_mutex;
+static int delay_timer = 0;
 
 /* Initialize this module.
  */
@@ -44,6 +49,8 @@ void init_client_module(void) {
 	}
 	banlist = NULL;
 	pthread_mutex_init(&ban_mutex, NULL);
+	wrong_password_list = NULL;
+	pthread_mutex_init(&pwd_mutex, NULL);
 }
 
 /* Add the session record of a client to the client_list.
@@ -483,6 +490,73 @@ int unban_ip(t_ip_addr *ip) {
 	return result;
 }
 
+int register_wrong_password(t_session *session) {
+	t_ipcounterlist *item;
+
+	if (session->config->ban_on_wrong_password == 0) {
+		return 0;
+	}
+
+	pthread_mutex_lock(&pwd_mutex);
+
+	item = wrong_password_list;
+	while (item != NULL) {
+		if (same_ip(&(item->ip), &(session->ip_address))) {
+			if (++(item->count) >= session->config->max_wrong_passwords) {
+				if (ip_allowed(&(session->ip_address), session->config->banlist_mask)) {
+					ban_ip(&(session->ip_address), session->config->ban_on_wrong_password, session->config->kick_on_ban);
+					session->keep_alive = false;
+					log_system(session, "Client banned because too many wrong passwords");
+				}
+			}
+
+			pthread_mutex_unlock(&pwd_mutex);
+			return 0;
+		}
+		item = item->next;
+	}
+
+	if ((item = (t_ipcounterlist*)malloc(sizeof(t_ipcounterlist))) == NULL) {
+		pthread_mutex_unlock(&pwd_mutex);
+		return -1;
+	}
+
+	copy_ip(&(item->ip), &(session->ip_address));
+	item->count = 1;
+	item->next = wrong_password_list;
+	wrong_password_list = item;
+
+	pthread_mutex_unlock(&pwd_mutex);
+
+	return 0;
+}
+
+void remove_wrong_password_list(t_config *config) {
+	t_ipcounterlist *item, *remove;
+
+	if ((config->ban_on_wrong_password == 0) || (wrong_password_list == NULL)) {
+		return;
+	} else if (++delay_timer < MAX_PASSWORD_DELAY_TIMER) {
+		return;
+	}
+
+	pthread_mutex_lock(&pwd_mutex);
+
+	item = wrong_password_list;
+	wrong_password_list = NULL;
+
+	pthread_mutex_unlock(&pwd_mutex);
+
+	while (item != NULL) {
+		remove = item;
+		item = item->next;
+
+		free(remove);
+	}
+
+	delay_timer = 0;
+}
+
 #ifdef HAVE_COMMAND
 /* Print the list of current connections.
  */
@@ -580,5 +654,4 @@ int number_of_bans(void) {
 
 	return result;
 }
-
 #endif
