@@ -89,7 +89,7 @@ static int headerfield_to_environment(t_session *session, t_fcgi_buffer *fcgi_bu
 /* Set environment variables for CGI script.
  */
 void set_environment(t_session *session, t_fcgi_buffer *fcgi_buffer) {
-	char ip[MAX_IP_STR_LEN], len[20], value[10], *name;
+	char ip[MAX_IP_STR_LEN], len[20], value[10], *data;
 	size_t len1, len2;
 	t_keyvalue *envir;
 #ifdef HAVE_SSL
@@ -106,12 +106,12 @@ void set_environment(t_session *session, t_fcgi_buffer *fcgi_buffer) {
 	if (session->uri[session->uri_len - 1] == '/') {
 		len1 = session->uri_len;
 		len2 = strlen(session->host->start_file);
-		if ((name = (char*)malloc(len1 + len2 + 1)) != NULL) {
-			memcpy(name, session->uri, len1);
-			memcpy(name + len1, session->host->start_file, len2);
-			name[len1 + len2] = '\0';
-			add_to_environment(fcgi_buffer, "SCRIPT_NAME", name);
-			free(name);
+		if ((data = (char*)malloc(len1 + len2 + 1)) != NULL) {
+			memcpy(data, session->uri, len1);
+			memcpy(data + len1, session->host->start_file, len2);
+			data[len1 + len2] = '\0';
+			add_to_environment(fcgi_buffer, "SCRIPT_NAME", data);
+			free(data);
 		}
 	} else {
 		add_to_environment(fcgi_buffer, "SCRIPT_NAME", session->uri);
@@ -121,7 +121,9 @@ void set_environment(t_session *session, t_fcgi_buffer *fcgi_buffer) {
 #ifdef CYGWIN
 	if (session->config->platform == windows) {
 		if ((root = strdup(session->host->website_root)) != NULL) {
-			add_to_environment_chroot(session, fcgi_buffer, "DOCUMENT_ROOT", cygwin_to_windows(root));
+			if ((data = cygwin_to_windows(root)) != NULL) {
+				add_to_environment_chroot(session, fcgi_buffer, "DOCUMENT_ROOT", data);
+			}
 			free(root);
 		}
 	} else
