@@ -1123,7 +1123,7 @@ void handle_request_result(t_session *session, int result) {
 			log_system(session, "Client kicked");
 			break;
 		case rr_CMD_INJECTION:
-			log_request(session, result);
+			log_request(session, 400);
 			if (ip_allowed(&(session->ip_address), session->config->banlist_mask)) {
 				ban_ip(&(session->ip_address), session->config->ban_on_cmdi, session->config->kick_on_ban);
 				log_system(session, "Client banned because of command injection");
@@ -1131,7 +1131,7 @@ void handle_request_result(t_session *session, int result) {
 			send_code(session, 400);
 			break;
 		case rr_SQL_INJECTION:
-			log_request(session, result);
+			log_request(session, 400);
 			if (ip_allowed(&(session->ip_address), session->config->banlist_mask)) {
 				ban_ip(&(session->ip_address), session->config->ban_on_sqli, session->config->kick_on_ban);
 				log_system(session, "Client banned because of SQL injection");
@@ -1206,7 +1206,7 @@ void connection_handler(t_session *session) {
 
 #ifdef HAVE_SSL
 	if (session->binding->use_ssl) {
-		session->socket_open = ssl_accept(session->client_socket, &(session->ssl_data), session->binding->ssl_context);
+		session->socket_open = (ssl_accept(session->client_socket, &(session->ssl_data), session->binding->ssl_context) != -1);
 	} else
 #endif
 		session->socket_open = true;
@@ -1774,6 +1774,7 @@ int run_server(t_settings *settings) {
 				 */
 				check_ban_list(config);
 				check_delayed_remove_timers(config);
+				remove_wrong_password_list(config);
 				/* FastCGI check
 				 */
 				check_load_balancer(config);
