@@ -22,7 +22,9 @@ t_headerfield *parse_headerfields(char *line) {
 	t_headerfield *first, *headerfield;
 	char *value;
 
-	if (*line == '\0') {
+	if (line == NULL) {
+		return NULL;
+	} else if (*line == '\0') {
 		return NULL;
 	}
 
@@ -72,6 +74,10 @@ char *get_headerfield(char *key, t_headerfield *headerfields) {
 	char *retval = NULL;
 	int len;
 
+	if (key == NULL) {
+		return NULL;
+	}
+
 	len = strlen(key);
 	while (headerfields != NULL) {
 		if (strncasecmp(headerfields->data, key, len) == 0) {
@@ -102,14 +108,20 @@ t_headerfield *remove_headerfields(t_headerfield *headerfields) {
 /*---< charlist >-------------------------------------------------------------*/
 
 void init_charlist(t_charlist *list) {
-	list->size = 0;
-	list->item = NULL;
+	if (list != NULL) {
+		list->size = 0;
+		list->item = NULL;
+	}
 }
 
 int parse_charlist(char *value, t_charlist *list) {
 	char *scan;
 	int add = 1, i;
 
+	if ((value == NULL) || (list == NULL)) {
+		return -1;
+	}
+
 	scan = value;
 	while (*scan != '\0') {
 		if (*scan == ',') {
@@ -142,14 +154,20 @@ int parse_charlist(char *value, t_charlist *list) {
 }
 
 void copy_charlist(t_charlist *dest, t_charlist *src) {
-	dest->size = src->size;
-	dest->item = src->item;
+	if ((dest != NULL) && (src != NULL)) {
+		dest->size = src->size;
+		dest->item = src->item;
+	}
 }
 
 bool in_charlist(char *item, t_charlist *list) {
 	int i;
 
-	if (((i = list->size) > 0) && (item != NULL)) {
+	if ((item == NULL) || (list == NULL)) {
+		return false;
+	}
+
+	if ((i = list->size) > 0) {
 		while (i-- > 0) {
 			if (strcmp(*(list->item + i), item) == 0) {
 				return true;
@@ -165,21 +183,27 @@ void print_charlist(t_charlist *list) {
 	int i;
 
 	printf("print_charlist()::start\n");
-	for (i = 0; i < list->size; i++) {
-		printf("[%s]\n", *(list->item + i));
+	if (list != NULL) {
+		for (i = 0; i < list->size; i++) {
+			printf("[%s]\n", *(list->item + i));
+		}
+	} else {
+		printf("(NULL)\n");
 	}
 	printf("print_charlist()::stop\n");
 }
 #endif
 
 void remove_charlist(t_charlist *list) {
-	if (list->size > 0) {
-		do {
-			(list->size)--;
-			sfree(*(list->item + list->size));
-		} while (list->size > 0);
-		sfree(list->item);
-		list->item = NULL;
+	if (list != NULL) {
+		if (list->size > 0) {
+			do {
+				(list->size)--;
+				sfree(*(list->item + list->size));
+			} while (list->size > 0);
+			sfree(list->item);
+			list->item = NULL;
+		}
 	}
 }
 
@@ -193,7 +217,7 @@ t_accesslist *parse_accesslist(char *line, bool pwd_allowed, t_accesslist *list)
 	bool error = false;
 
 	if (line == NULL) {
-		return list;
+		return remove_accesslist(list);
 	}
 	if (list != NULL) {
 		new = list;
@@ -339,30 +363,32 @@ int parse_keyvaluelist(char *line, t_keyvalue **kvlist, char *delimiter) {
 	char *value;
 	t_keyvalue *prev;
 
-	if (line != NULL) {
-		if ((value = strstr(line, delimiter)) != NULL) {
-			*value = '\0';
-			value += strlen(delimiter);
+	if ((line == NULL) || (kvlist == NULL) || (delimiter == NULL)) {
+		return -1;
+	}
 
-			prev = *kvlist;
-			if ((*kvlist = (t_keyvalue*)malloc(sizeof(t_keyvalue))) == NULL) {
-				return -1;
-			}
-			(*kvlist)->next = prev;
+	if ((value = strstr(line, delimiter)) != NULL) {
+		*value = '\0';
+		value += strlen(delimiter);
 
-			(*kvlist)->value = NULL;
-			if (((*kvlist)->key = strdup(remove_spaces(line))) == NULL) {
-				free(*kvlist);
-				return -1;
-			}
-			if (((*kvlist)->value = strdup(remove_spaces(value))) == NULL) {
-				free((*kvlist)->key);
-				free(*kvlist);
-				return -1;
-			}
-		} else {
+		prev = *kvlist;
+		if ((*kvlist = (t_keyvalue*)malloc(sizeof(t_keyvalue))) == NULL) {
 			return -1;
 		}
+		(*kvlist)->next = prev;
+
+		(*kvlist)->value = NULL;
+		if (((*kvlist)->key = strdup(remove_spaces(line))) == NULL) {
+			free(*kvlist);
+			return -1;
+		}
+		if (((*kvlist)->value = strdup(remove_spaces(value))) == NULL) {
+			free((*kvlist)->key);
+			free(*kvlist);
+			return -1;
+		}
+	} else {
+		return -1;
 	}
 
 	return 0;
@@ -388,17 +414,19 @@ t_keyvalue *remove_keyvaluelist(t_keyvalue *list) {
 int register_tempdata(t_tempdata **tempdata, void *data, t_tempdata_type type) {
 	t_tempdata *tdata;
 
-	if ((tempdata != NULL) && (data != NULL)) {
-		if ((tdata = (t_tempdata*)malloc(sizeof(t_tempdata))) == NULL) {
-			return -1;
-		}
-
-		tdata->content = data;
-		tdata->type = type;
-		tdata->next = *tempdata;
-		*tempdata = tdata;
+	if (tempdata == NULL) {
+		return 0;
+	} else if (data == NULL) {
+		return -1;
+	} else if ((tdata = (t_tempdata*)malloc(sizeof(t_tempdata))) == NULL) {
+		return -1;
 	}
 
+	tdata->content = data;
+	tdata->type = type;
+	tdata->next = *tempdata;
+	*tempdata = tdata;
+
 	return 0;
 }
 
