@@ -63,7 +63,7 @@ char *remove_spaces(char *str) {
 
 /* Remove comment from a string.
  */
-char *strip_line(char *str) {
+char *uncomment(char *str) {
 	char *hash;
 
 	if (str != NULL) {
@@ -79,11 +79,11 @@ char *strip_line(char *str) {
 
 /* Covert a string to lowercase.
  */
-char *strlower(char *line) {
+char *strlower(char *str) {
 	char *c;
 
-	if (line != NULL) {
-		c = line;
+	if (str != NULL) {
+		c = str;
 		while (*c != '\0') {
 			if ((*c >= 'A') && (*c <= 'Z')) {
 				*c += 32;
@@ -92,30 +92,37 @@ char *strlower(char *line) {
 		}
 	}
 
-	return line;
+	return str;
 }
 
 /* Split a string in 2 strings.
  */
 int split_string(const char *str, char **key, char **value, char c) {
-	if (str != NULL) {
-		*key = (char*)str;
-		if ((*value = strchr(*key, c)) != NULL) {
-			*(*value)++ = '\0';
-			*key = remove_spaces(*key);
-			*value = remove_spaces(*value);
+	if ((str == NULL) || (key == NULL) || (value == NULL)) {
+		return -1;
+	}
 
-			return 0;
-		}
+	*key = (char*)str;
+	if ((*value = strchr(*key, c)) != NULL) {
+		*(*value)++ = '\0';
+		*key = remove_spaces(*key);
+		*value = remove_spaces(*value);
+
+		return 0;
 	}
 
 	return -1;
 }
 
 int split_configline(const char *str, char **key, char **value) {
+	int eq = 0;
+
+	if ((str == NULL) || (key == NULL) || (value == NULL)) {
+		return -1;
+	}
+
 	*key = remove_spaces((char*)str);
 	*value = *key;
-	int eq = 0;
 
 	while (**value != '\0') {
 		if ((**value == ' ') || (**value == '=')) {
@@ -131,6 +138,7 @@ int split_configline(const char *str, char **key, char **value) {
 		}
 		(*value)++;
 	}
+
 	value = NULL;
 
 	return -1;
@@ -184,48 +192,51 @@ static short hex_to_int(char c) {
 
 /* Decode the URL encoded characters (%XX).
  */
-void url_decode(char *line) {
+void url_decode(char *str) {
 	short low, high;
-	char *dest = line;
+	char *dest = str;
 
-	if (line != NULL) {
-		while (*line != '\0') {
-			if (*line == '%') {
-				if ((high = hex_to_int(*(line + 1))) != -1) {
-					if ((low = hex_to_int(*(line + 2))) != -1) {
-						line += 2;
-						*line = (char)(high<<4) + low;
-					}
+	if (str == NULL) {
+		return;
+	}
+
+	while (*str != '\0') {
+		if (*str == '%') {
+			if ((high = hex_to_int(*(str + 1))) != -1) {
+				if ((low = hex_to_int(*(str + 2))) != -1) {
+					str += 2;
+					*str = (char)(high<<4) + low;
 				}
 			}
-			*(dest++) = *(line++);
 		}
-		*dest = *line;
+		*(dest++) = *(str++);
 	}
+
+	*dest = '\0';
 }
 
 /* Scan for characters with ASCII value < 32.
  */
-bool forbidden_chars_present(char *line) {
+bool forbidden_chars_present(char *str) {
 	short low, high;
 
-	if (line == NULL) {
+	if (str == NULL) {
 		return false;
 	}
 
-	while (*line != '\0') {
-		if ((*line > 0) && (*line < 32)) {
+	while (*str != '\0') {
+		if ((*str > 0) && (*str < 32)) {
 			return true;
-		} else if (*line == '%') {
-			if ((high = hex_to_int(*(line + 1))) != -1) {
-				if ((low = hex_to_int(*(line + 2))) != -1) {
+		} else if (*str == '%') {
+			if ((high = hex_to_int(*(str + 1))) != -1) {
+				if ((low = hex_to_int(*(str + 2))) != -1) {
 					if (((high<<4) + low) < 32) {
 						return true;
 					}
 				}
 			}
 		}
-		line++;
+		str++;
 	}
 
 	return false;
@@ -233,32 +244,37 @@ bool forbidden_chars_present(char *line) {
 
 /* Prevent Command injection.
  */
-int prevent_CMDi(char *line) {
+int prevent_CMDi(char *str) {
 	int result = 0;
 	short low, high;
 	char value, *prot;
 
-	prot = line;
+	if (str == NULL) {
+		return 0;
+	}
+
+	prot = str;
 	while ((prot = strcasestr(prot, "http://")) != NULL) {
 		memcpy(prot, "xxxx", 4);
 		prot += 7;
+		result++;
 	}
 
-	if (line != NULL) {
-		while (*line != '\0') {
-			if ((value = *line) == '%') {
-				if ((high = hex_to_int(*(line + 1))) != -1) {
-					if ((low = hex_to_int(*(line + 2))) != -1) {
+	if (str != NULL) {
+		while (*str != '\0') {
+			if ((value = *str) == '%') {
+				if ((high = hex_to_int(*(str + 1))) != -1) {
+					if ((low = hex_to_int(*(str + 2))) != -1) {
 						value = (char)(high<<4) + low;
 					}
 				}
 			}
 
 			if ((value == '|') || (value == ';') || (value == '`')) {
-				*line = '_';
+				*str = '_';
 				result += 1;
 			}
-			line++;
+			str++;
 		}
 	}
 
@@ -267,49 +283,49 @@ int prevent_CMDi(char *line) {
 
 /* Prevent SQL injection
  */
-int prevent_SQLi(char *line, int length, char **newline) {
+int prevent_SQLi(char *str, int length, char **newstr) {
 	int changed = 0, i, add, left, newlength = 0;
 	char *temp, value;
 	short low, high;
 
-	if ((line == NULL) || (length == 0)) {
+	if ((str == NULL) || (length == 0) || (newstr == NULL)) {
 		return 0;
 	}
 
 	add = left = 32;
-	if ((*newline = (char*)malloc(length + add)) == NULL) {
+	if ((*newstr = (char*)malloc(length + add)) == NULL) {
 		return -1;
 	}
 	for (i = 0; i < length; i++) {
-		value = *(line + i);
+		value = *(str + i);
 
 		if ((value == '%') && (i + 2 < length)) {
-			if ((high = hex_to_int(*(line + i + 1))) != -1) {
-				if ((low = hex_to_int(*(line + i + 2))) != -1) {
+			if ((high = hex_to_int(*(str + i + 1))) != -1) {
+				if ((low = hex_to_int(*(str + i + 2))) != -1) {
 					value = (char)(high<<4) + low;
 				}
 			}
 		}
 
 		if ((value == '\'') || (value == '`') || (value == '\\')) {
-			*(*newline + newlength++) = '\\';
+			*(*newstr + newlength++) = '\\';
 			if (left-- == 0) {
 				add += left = 32;
-				if ((temp = (char*)realloc(*newline, length + add)) == NULL) {
-					free(*newline);
+				if ((temp = (char*)realloc(*newstr, length + add)) == NULL) {
+					free(*newstr);
 					return -1;
 				} else {
-					*newline = temp;
+					*newstr = temp;
 				}
 			}
 			changed++;
 		}
-		*(*newline + (newlength++)) = *(line + i);
+		*(*newstr + (newlength++)) = *(str + i);
 	}
 
 	if (changed == 0) {
-		free(*newline);
-		*newline = NULL;
+		free(*newstr);
+		*newstr = NULL;
 		newlength = 0;
 	}
 
@@ -318,27 +334,29 @@ int prevent_SQLi(char *line, int length, char **newline) {
 
 /* Prevent cross-site scripting.
  */
-int prevent_XSS(char *line) {
+int prevent_XSS(char *str) {
 	int result = 0;
 	short low, high;
 	char value;
 
-	if (line != NULL) {
-		while (*line != '\0') {
-			if ((value = *line) == '%') {
-				if ((high = hex_to_int(*(line + 1))) != -1) {
-					if ((low = hex_to_int(*(line + 2))) != -1) {
-						value = (char)(high<<4) + low;
-					}
+	if (str == NULL) {
+		return 0;
+	}
+
+	while (*str != '\0') {
+		if ((value = *str) == '%') {
+			if ((high = hex_to_int(*(str + 1))) != -1) {
+				if ((low = hex_to_int(*(str + 2))) != -1) {
+					value = (char)(high<<4) + low;
 				}
 			}
-
-			if ((value == '\"') || (value == '<') || (value == '>') || (value == '\'')) {
-				*line = '_';
-				result += 1;
-			}
-			line++;
 		}
+
+		if ((value == '\"') || (value == '<') || (value == '>') || (value == '\'')) {
+			*str = '_';
+			result += 1;
+		}
+		str++;
 	}
 
 	return result;
@@ -514,32 +532,34 @@ int str_replace(char *src, char *from, char *to, char **dst) {
 	char *pos;
 	int replaced = 0, len_from, len_to;
 
+	if ((src == NULL) || (from == NULL) || (to == NULL) || (dst == NULL)) {
+		return 0;
+	}
+
 	len_from = strlen(from);
 	len_to   = strlen(to);
 
-	if ((src != NULL) && (from != NULL) && (to != NULL)) {
-		while ((pos = strstr(src, from)) != NULL) {
-			if ((*dst = (char*)malloc(strlen(src) - len_from + len_to + 1)) == NULL) {
-				if (*dst != NULL) {
-					free(*dst);
-				}
-				return -1;
+	while ((pos = strstr(src, from)) != NULL) {
+		if ((*dst = (char*)malloc(strlen(src) - len_from + len_to + 1)) == NULL) {
+			if (*dst != NULL) {
+				free(*dst);
 			}
-
-			*pos = '\0';
-			sprintf(*dst, "%s%s%s", src, to, pos + len_from);
-
-			if (replaced > 0) {
-				free(src);
-			}
-			if (replaced++ == 1000) {
-				if (*dst != NULL) {
-					free(*dst);
-				}
-				return -1;
-			}
-			src = *dst;
+			return -1;
 		}
+
+		*pos = '\0';
+		sprintf(*dst, "%s%s%s", src, to, pos + len_from);
+
+		if (replaced > 0) {
+			free(src);
+		}
+		if (replaced++ == 1000) {
+			if (*dst != NULL) {
+				free(*dst);
+			}
+			return -1;
+		}
+		src = *dst;
 	}
 
 	return replaced;
@@ -548,11 +568,13 @@ int str_replace(char *src, char *from, char *to, char **dst) {
 bool min_strlen(char *str, int n) {
 	int i = 0;
 
-	while (i < n) {
-		if (*(str + i) == '\0') {
-			return false;
+	if (str != NULL) {
+		while (i < n) {
+			if (*(str + i) == '\0') {
+				return false;
+			}
+			i++;
 		}
-		i++;
 	}
 
 	return true;
