@@ -5,7 +5,7 @@
 
 int  str2int(const char *str);
 char *remove_spaces(char *str);
-char *strip_line(char *str);
+char *uncomment(char *str);
 char *strlower(char *line);
 int  split_string(const char *str, char **key, char **value, char c);
 int  split_configline(const char *str, char **key, char **value);
