@@ -260,8 +260,10 @@ t_config *default_config(void) {
 		config->ban_on_cmdi        = 0;
 		config->ban_on_sqli        = 0;
 		config->ban_on_timeout     = 0;
+		config->ban_on_wrong_password = 0;
 		config->kick_on_ban        = false;
 		config->reban_during_ban   = false;
+		config->max_wrong_passwords = 0;
 		config->flooding_count     = 0;
 		config->flooding_time      = 0;
 		config->reconnect_delay    = 0;
@@ -690,6 +692,12 @@ static bool system_setting(char *key, char *value, t_config *config) {
 		if ((config->ban_on_timeout = str2int(value)) != -1) {
 			return true;
 		}
+	} else if (strcmp(key, "banonwrongpassword") == 0) {
+		if (split_string(value, &value, &rest, ':') == -1) {
+		} else if ((config->max_wrong_passwords = str2int(value)) <= 0) {
+		} else if ((config->ban_on_wrong_password = str2int(rest)) > 0) {
+			return true;
+		}
 #ifdef HAVE_CACHE
 	} else if (strcmp(key, "cachemaxfilesize") == 0) {
 		if ((config->cache_max_filesize = str2int(value)) != -1) {
@@ -1510,7 +1518,7 @@ int read_main_configfile(char *configfile, t_config *config, bool config_check)
 		}
 		counter += lines_read;
 
-		key = strip_line(line);
+		key = uncomment(line);
 		if (*key != '\0') {
 			variables_replaced = false;
 
@@ -1777,7 +1785,7 @@ int read_user_configfile(char *configfile, t_host *host, t_tempdata **tempdata)
 		}
 		counter += lines_read;
 
-		key = strip_line(line);
+		key = uncomment(line);
 		if (*key != '\0') {
 			if (split_configline(key, &key, &value) != -1) {
 				strlower(key);
