@@ -205,7 +205,9 @@ int get_homedir(t_session *session, char *username) {
 	int len;
 	char *old_root;
 
-	if ((pwd = getpwnam(username)) != NULL) {
+	if (username == NULL) {
+		return 500;
+	} else if ((pwd = getpwnam(username)) != NULL) {
 		len = strlen(pwd->pw_dir);
 		old_root = session->host->website_root;
 		if ((session->host->website_root = (char*)malloc(len + strlen(session->config->user_directory) + 2)) == NULL) {
