@@ -727,15 +727,27 @@ int execute_cgi(t_session *session) {
 						 */
 						*(cgi_info.input_buffer + cgi_info.input_len) = '\0';
 
-						if ((new_line = strstr(cgi_info.input_buffer, "\r\n\r\n")) != NULL) {
+						if ((new_line = strstr(cgi_info.input_buffer, "\r\n\r\n")) == NULL) {
+							/* Fix crappy CGI headers
+							 */
+							if ((result = fix_crappy_cgi_headers(&cgi_info)) == -1) {
+								retval = -1;
+								break;
+							} else if (result == 0) {
+								new_line = strstr(cgi_info.input_buffer, "\r\n\r\n");
+							}
+						}
+
+						if (new_line != NULL) {
 							*(new_line + 2) = '\0';
 							if (session->throttle == 0) {
 								if ((contyp_start = strcasestr(cgi_info.input_buffer, hs_contyp)) != NULL) {
 									if ((contyp_end = strchr(contyp_start, '\r')) != NULL) {
 										contyp_start += 14;
+										c = *contyp_end;
 										*contyp_end = '\0';
 										session->throttle = get_throttlespeed(contyp_start, session->config->throttle);
-										*contyp_end = '\r';
+										*contyp_end = c;
 									}
 								}
 							}
@@ -755,6 +767,8 @@ int execute_cgi(t_session *session) {
 										*line = '\0';
 										retval = str2int(code);
 										*line = c;
+
+										*(new_line + 2) = '\r';
 										break;
 									}
 									line++;
@@ -848,8 +862,6 @@ int execute_cgi(t_session *session) {
 				} else {
 					if (cgi_info.input_len == 0) {
 						log_error(session, "no output");
-					} else if (strstr(cgi_info.input_buffer, "\r\n\r\n") == NULL) {
-						log_error(session, "non-RFC HTTP header ('\\n' instead of '\\r\\n')");
 					} else {
 						log_error(session, "CGI only printed a HTTP header, no content");
 					}
