@@ -191,7 +191,7 @@ int read_file(char *config_file, t_line **config, t_line **aliases, bool handle_
 		}
 
 		linenr += lines_read;
-		data = strip_line(line);
+		data = uncomment(line);
 		if ((data[0] == '#') || (data[0] == '\0')) {
 			continue;
 		}
